
#ifndef GDHCPD_reread_button_clicked_H
#	define GDHCPD_reread_button_clicked_H

void reread_button_clicked(struct w *widgets);

#endif
